<?php

namespace LakeDrops\ComposerScripts;

use Composer\Composer;
use Composer\IO\IOInterface;
use Composer\Script\Event;
use LakeDrops\Component\Composer\Utils;

/**
 * Class Handler.
 *
 * @package LakeDrops\Drupal8Scaffold
 */
class Handler {

  /**
   * The composer object running this session.
   *
   * @var \Composer\Composer
   */
  protected $composer;

  /**
   * The input-output object for the composer session.
   *
   * @var \Composer\IO\IOInterface
   */
  protected $io;

  /**
   * Handler constructor.
   *
   * @param \Composer\Composer $composer
   *   The composer object.
   * @param \Composer\IO\IOInterface $io
   *   The input-output object.
   */
  public function __construct(Composer $composer, IOInterface $io) {
    $this->composer = $composer;
    $this->io = $io;
  }

  /**
   * Retrieve a package from the current composer process.
   *
   * @param string $name
   *   Name of the package to get from the current composer installation.
   *
   * @return \Composer\Package\PackageInterface
   *   The package.
   */
  protected function getPackage($name) {
    return $this->composer->getRepositoryManager()->getLocalRepository()->findPackage($name, '*');
  }

  /**
   * Update scripts of all LakeDrops plugins.
   *
   * @param \Composer\Script\Event $event
   *   The event that triggered the plugin.
   */
  public function updateScripts(Event $event) {

    // We only do the fancy stuff for developers.
    if (!$event->isDevMode()) {
      return;
    }

    $settings = new Utils($this->composer);
    $scripts = $settings->getSection('scripts');
    $scriptDescriptions = $settings->getSubSection('extra', 'scripts-description');
    $installationManager = $this->composer->getInstallationManager();
    foreach ($this->composer->getRepositoryManager()->getLocalRepository()->search('lakedrops/*') as $pkg) {
      $pluginRoot = $installationManager->getInstallPath($this->getPackage($pkg['name']));
      $pluginSettings = new Utils($this->composer, $pluginRoot);
      foreach ($pluginSettings->getSubSubSection('extra', 'lakedrops', 'scripts') as $name => $script) {
        $scripts[$name] = $script['callback'];
        $scriptDescriptions[$name] = $script['description'];
      }
    }

    $settings->setSection('scripts', $scripts);
    $settings->setSubSection('extra', 'scripts-description', $scriptDescriptions);
    $settings->write();
  }

}
